"""
Constants use for login via id.egov.uz
"""

BASE_URL = 'https://id.egov.uz/'
AUTHORIZE_URL = 'http://sso.egov.uz:8443/sso/oauth/Authorization.do' # noqa
ACCESS_TOKEN_URL = 'http://sso.egov.uz:8443/sso/oauth/Authorization.do' # noqa
PROFILE_URL = 'http://sso.egov.uz:8443/sso/oauth/Authorization.do' # noqa